@@ -6,7 +6,34 @@ as well as ACs and lowqual fields. Note that this table doesn't
 split multi-allelic sites.
 
 Generates info.ht, info-split.ht, needed for sample_qc and for 
-random forest jobs.
+random forest jobs. Generated fields:
+
+lowqual
+AS_lowqual
+info
+  ReadPosRankSum
+  MQRankSum
+  QUALapprox
+  VarDP
+  SB
+  MQ
+  QD
+  FS
+  SOR
+  AS_ReadPosRankSum
+  AS_MQRankSum
+  AS_QUALapprox
+  AS_VarDP
+  AS_MQ
+  AS_QD
+  AS_SB_TABLE
+  AS_FS
+  AS_SOR
+  AC_raw
+  AC
+  AS_pab_max
+a_index
+was_split
 """
 
 import logging
@@ -35,11 +62,6 @@ logger.setLevel(logging.INFO)
 
 @click.command()
 @click.version_option(_version.__version__)
-@click.option(
-    '--out-info-ht',
-    'out_info_ht_path',
-    required=True,
-)
 @click.option(
     '--out-split-info-ht',
     'out_split_info_ht_path',
@@ -65,7 +87,6 @@ logger.setLevel(logging.INFO)
     'that generates it.',
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-statements,missing-function-docstring
-    out_info_ht_path: str,
     out_split_info_ht_path: str,
     mt_path: str,
     local_tmp_dir: str,
@@ -77,7 +98,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-stateme
 
     compute_info(
         mt=all_samples_mt,
-        out_ht_path=out_info_ht_path,
         out_split_ht_path=out_split_info_ht_path,
         overwrite=overwrite,
     )
@@ -85,7 +105,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,too-many-stateme
 
 def compute_info(
     mt: hl.MatrixTable,
-    out_ht_path: str,
     out_split_ht_path: str,
     overwrite: bool = False,
 ) -> hl.Table:
@@ -100,94 +119,90 @@ def compute_info(
     :param overwrite: overwrite checkpoints if they exist
     :return: Table with info fields
     """
-    if not overwrite and file_exists(out_ht_path):
-        info_ht = hl.read_table(out_ht_path)
-    else:
-        mt = mt.filter_rows((hl.len(mt.alleles) > 1))
-        mt = mt.transmute_entries(**mt.gvcf_info)
-        mt = mt.annotate_rows(alt_alleles_range_array=hl.range(1, hl.len(mt.alleles)))
+    if not overwrite and file_exists(out_split_ht_path):
+        return hl.read_table(out_split_ht_path)
+        
+    mt = mt.filter_rows((hl.len(mt.alleles) > 1))
+    mt = mt.transmute_entries(**mt.gvcf_info)
+    mt = mt.annotate_rows(alt_alleles_range_array=hl.range(1, hl.len(mt.alleles)))
 
-        # Compute AS and site level info expr
-        # Note that production defaults have changed:
-        # For new releases, the `RAW_MQandDP` field replaces the `RAW_MQ` and `MQ_DP` fields
-        info_expr = get_site_info_expr(
+    # Compute AS and site level info expr
+    # Note that production defaults have changed:
+    # For new releases, the `RAW_MQandDP` field replaces the `RAW_MQ` and `MQ_DP` fields
+    info_expr = get_site_info_expr(
+        mt,
+        sum_agg_fields=INFO_SUM_AGG_FIELDS,
+        int32_sum_agg_fields=INFO_INT32_SUM_AGG_FIELDS,
+        array_sum_agg_fields=['SB', 'RAW_MQandDP'],
+    )
+    info_expr = info_expr.annotate(
+        **get_as_info_expr(
             mt,
             sum_agg_fields=INFO_SUM_AGG_FIELDS,
             int32_sum_agg_fields=INFO_INT32_SUM_AGG_FIELDS,
             array_sum_agg_fields=['SB', 'RAW_MQandDP'],
         )
-        info_expr = info_expr.annotate(
-            **get_as_info_expr(
-                mt,
-                sum_agg_fields=INFO_SUM_AGG_FIELDS,
-                int32_sum_agg_fields=INFO_INT32_SUM_AGG_FIELDS,
-                array_sum_agg_fields=['SB', 'RAW_MQandDP'],
-            )
-        )
+    )
 
-        # Add AC and AC_raw:
-        # First compute ACs for each non-ref allele, grouped by adj
-        grp_ac_expr = hl.agg.array_agg(
+    # Add AC and AC_raw:
+    # First compute ACs for each non-ref allele, grouped by adj
+    grp_ac_expr = hl.agg.array_agg(
+        lambda ai: hl.agg.filter(
+            mt.LA.contains(ai),
+            hl.agg.group_by(
+                get_adj_expr(mt.LGT, mt.GQ, mt.DP, mt.LAD),
+                hl.agg.sum(
+                    mt.LGT.one_hot_alleles(mt.LA.map(hl.str))[mt.LA.index(ai)]
+                ),
+            ),
+        ),
+        mt.alt_alleles_range_array,
+    )
+
+    # Then, for each non-ref allele, compute
+    # AC as the adj group
+    # AC_raw as the sum of adj and non-adj groups
+    info_expr = info_expr.annotate(
+        AC_raw=grp_ac_expr.map(
+            lambda i: hl.int32(i.get(True, 0) + i.get(False, 0))
+        ),
+        AC=grp_ac_expr.map(lambda i: hl.int32(i.get(True, 0))),
+    )
+
+    # Annotating raw MT with pab max
+    info_expr = info_expr.annotate(
+        AS_pab_max=hl.agg.array_agg(
             lambda ai: hl.agg.filter(
-                mt.LA.contains(ai),
-                hl.agg.group_by(
-                    get_adj_expr(mt.LGT, mt.GQ, mt.DP, mt.LAD),
-                    hl.agg.sum(
-                        mt.LGT.one_hot_alleles(mt.LA.map(hl.str))[mt.LA.index(ai)]
-                    ),
+                mt.LA.contains(ai) & mt.LGT.is_het(),
+                hl.agg.max(
+                    hl.binom_test(
+                        mt.LAD[mt.LA.index(ai)], hl.sum(mt.LAD), 0.5, 'two-sided'
+                    )
                 ),
             ),
             mt.alt_alleles_range_array,
         )
+    )
 
-        # Then, for each non-ref allele, compute
-        # AC as the adj group
-        # AC_raw as the sum of adj and non-adj groups
-        info_expr = info_expr.annotate(
-            AC_raw=grp_ac_expr.map(
-                lambda i: hl.int32(i.get(True, 0) + i.get(False, 0))
-            ),
-            AC=grp_ac_expr.map(lambda i: hl.int32(i.get(True, 0))),
-        )
+    info_ht = mt.select_rows(info=info_expr).rows()
 
-        # Annotating raw MT with pab max
-        info_expr = info_expr.annotate(
-            AS_pab_max=hl.agg.array_agg(
-                lambda ai: hl.agg.filter(
-                    mt.LA.contains(ai) & mt.LGT.is_het(),
-                    hl.agg.max(
-                        hl.binom_test(
-                            mt.LAD[mt.LA.index(ai)], hl.sum(mt.LAD), 0.5, 'two-sided'
-                        )
-                    ),
-                ),
-                mt.alt_alleles_range_array,
-            )
-        )
-
-        info_ht = mt.select_rows(info=info_expr).rows()
-
-        # Add lowqual flag
-        info_ht = info_ht.annotate(
-            lowqual=get_lowqual_expr(
-                info_ht.alleles,
-                info_ht.info.QUALapprox,
-                # The indel het prior used for gnomad v3 was 1/10k bases (phred=40).
-                # This value is usually 1/8k bases (phred=39).
-                indel_phred_het_prior=40,
-            ),
-            AS_lowqual=get_lowqual_expr(
-                info_ht.alleles, info_ht.info.AS_QUALapprox, indel_phred_het_prior=40
-            ),
-        )
-        info_ht = info_ht.naive_coalesce(7500)
-        info_ht.write(out_ht_path, overwrite=True)
-
-    if out_split_ht_path and (overwrite or not file_exists(out_split_ht_path)):
-        split_info_ht = split_multiallelic_in_info_table(info_ht)
-        split_info_ht.write(out_split_ht_path, overwrite=True)
-
-    return info_ht
+    # Add lowqual flag
+    info_ht = info_ht.annotate(
+        lowqual=get_lowqual_expr(
+            info_ht.alleles,
+            info_ht.info.QUALapprox,
+            # The indel het prior used for gnomad v3 was 1/10k bases (phred=40).
+            # This value is usually 1/8k bases (phred=39).
+            indel_phred_het_prior=40,
+        ),
+        AS_lowqual=get_lowqual_expr(
+            info_ht.alleles, info_ht.info.AS_QUALapprox, indel_phred_het_prior=40
+        ),
+    )
+    info_ht = info_ht.naive_coalesce(7500)
+    split_info_ht = split_multiallelic_in_info_table(info_ht)
+    split_info_ht.write(out_split_ht_path, overwrite=True)
+    return split_info_ht
 
 
 def split_multiallelic_in_info_table(info_ht: hl.Table) -> hl.Table:
